@@ -8,7 +8,7 @@
 #define KMAHJONGGTILESETSELECTOR_H
 
 // Qt
-#include <QMap>
+#include <QHash>
 
 // KF
 #include <KConfigSkeleton>
@@ -18,17 +18,21 @@
 
 class KMahjonggTileset;
 
-class KMahjonggTilesetSelector : public QWidget, public Ui::KMahjonggTilesetSelector
+class KMahjonggTilesetSelector : public QWidget, private Ui::KMahjonggTilesetSelector
 {
-Q_OBJECT
-  public:
-    explicit KMahjonggTilesetSelector( QWidget* parent, KConfigSkeleton * aconfig );
-    ~KMahjonggTilesetSelector();
-    void setupData(KConfigSkeleton * aconfig);
+    Q_OBJECT
 
-    QMap<QString, KMahjonggTileset *> tilesetMap;
-  public Q_SLOTS:
+public:
+    explicit KMahjonggTilesetSelector(QWidget *parent, KConfigSkeleton *aconfig);
+    ~KMahjonggTilesetSelector() override;
+
+    void setupData(KConfigSkeleton *aconfig);
+
+public Q_SLOTS:
     void tilesetChanged();
+
+private:
+    QHash<QString, KMahjonggTileset *> tilesetMap;
 };
 
 #endif // KMAHJONGGTILESETSELECTOR_H
